@@ -1,8 +1,9 @@
-from typing import Any, Dict, Optional, Sequence
+from typing import Any, Dict, Optional, Sequence, Type
 
-from pydantic import ValidationError, create_model
+from pydantic import BaseModel, ValidationError, create_model
 from pydantic.error_wrappers import ErrorList
 from starlette.exceptions import HTTPException as StarletteHTTPException
+from starlette.exceptions import WebSocketException as WebSocketException  # noqa: F401
 
 
 class HTTPException(StarletteHTTPException):
@@ -10,14 +11,13 @@ class HTTPException(StarletteHTTPException):
         self,
         status_code: int,
         detail: Any = None,
-        headers: Optional[Dict[str, Any]] = None,
+        headers: Optional[Dict[str, str]] = None,
     ) -> None:
-        super().__init__(status_code=status_code, detail=detail)
-        self.headers = headers
+        super().__init__(status_code=status_code, detail=detail, headers=headers)
 
 
-RequestErrorModel = create_model("Request")
-WebSocketErrorModel = create_model("WebSocket")
+RequestErrorModel: Type[BaseModel] = create_model("Request")
+WebSocketErrorModel: Type[BaseModel] = create_model("WebSocket")
 
 
 class FastAPIError(RuntimeError):
